# wavelet transform in larch
# follows method of Munuz, Argoul, and Farges

import numpy as np
import matplotlib.pyplot as plt
import matplotlib.cm as cm
import matplotlib.mlab as ml
import larch
from larch import ValidateLarchPlugin
from larch.io import read_ascii
#from larch.io import read_xdi
from larch.xafs import autobk
from larch.xafs import xftf
from larch.symboltable import Group
from larch import Make_CallArgs, parse_group_args
from larch.math import complex_phase
from larch_plugins.xafs import set_xafsGroup
from larch.xafs import cauchy_wavelet
from wxmplot.interactive import newplot
from wxmplot.interactive import plot

_larch = larch.Interpreter()
f = read_ascii('Cu_foil.xmu', labels = 'energy mu')
#f = read_ascii('Cu_EXAFS_Cu_Foil_Scan2_20211209T133525.xdi', labels = 'energy i0 i1 i2 mu')
autobk(f, kmin=0.0, kmax=16.0, rbkg=1.0, kweight=2, e0=8979,win='hanning', _larch=_larch)

kopts = {'xlabel': r'$k \,(\AA^{-1})$', 
         'ylabel': r'$k^2\chi(k) \, (\AA^{-2})$', 
         'linewidth': 3, 'title': 'Cu Foil', 'show_legend':True}

newplot(f.k, f.chi*f.k**2, win=1, label='original data', **kopts)

# do wavelet transform (no window function yet)
cauchy_wavelet(f, kweight=2, _larch=_larch)
# display wavelet magnitude, real part
# horizontal axis is k, vertical is R
imopts = {'x': f.k, 'y': f.r}

#plt.imshow(f.wcauchy_mag)
#plt.show()

plt.imshow(f.wcauchy_mag, win=1, label='Wavelet Transform: Magnitude', **imopts)
plt.imshow(f.wcauchy_re,  win=2, label='Wavelet Transform: Real Part', **imopts)

# plot wavelet projected to k space
plot(f.k, f.wcauchy_re.sum(axis=0), win=1, label='projected wavelet', **kopts)

ropts = kopts
ropts['xlabel'] = r'$R \, (\AA) $'
ropts['ylabel'] = r'$|\chi(R)| \, (\AA^{-3})$'

# plot wavelet projected to R space
newplot(f.r, f.wcauchy_mag.sum(axis=1), win=2,  label='projected wavelet', **ropts)